Module blaxel.core.common.settings
==================================

Classes
-------

`Settings()`
:   

    ### Class variables

    `auth: blaxel.core.authentication.types.BlaxelAuth`
    :   The type of the None singleton.

    ### Instance variables

    `base_url: str`
    :   Get the base URL for the API.

    `bl_cloud: bool`
    :   Is running on bl cloud.

    `enable_opentelemetry: bool`
    :   Get the enable opentelemetry.

    `env: str`
    :   Get the environment.

    `generation: str`
    :   Get the generation.

    `headers: Dict[str, str]`
    :   Get the headers for API requests.

    `log_level: str`
    :   Get the log level.

    `name: str`
    :   Get the name.

    `run_internal_hostname: str`
    :   Get the run internal hostname.

    `run_internal_protocol: str`
    :   Get the run internal protocol.

    `run_url: str`
    :   Get the run URL.

    `type: str`
    :   Get the type.

    `version: str`
    :   Get the package version.

    `workspace: str`
    :   Get the workspace.